%define name	dspam
%define version	3.8.0
%define release	1%{?dist}

%define libname	dspam-libs

Summary:	A library and Mail Delivery Agent for Bayesian spam filtering
Name:		%{name}
Version:	%{version}
Release:	%{release}
License:	GPL
Group:		Networking/Mail
Source0:	%{name}-%{version}.tar.gz
#Patch0:		dspam-3.2.0-shared_tools.patch.bz2
URL:		http://www.nuclearelephant.com/projects/dspam/
PreReq:		%{libname} = %{version}-%{release}
Buildroot:	%{_tmppath}/%{name}-%{version}-root
Provides:	perl(configure.pl)
BuildRequires:	libtool, sqlite-devel

%description
DSPAM (as in De-Spam) is an open-source project to create a new
kind of anti-spam mechanism, and is currently effective as both a
server-side agent for UNIX email servers and a developer's library
for mail clients, other anti-spam tools, and similar projects
requiring drop-in spam filtering.

The DSPAM agent masquerades as the email server's local delivery
agent and filters/learns spams using an advanced Bayesian
statistical approach (based on Baye's theorem of combined
probabilities) which provides an administratively
maintenance-free, easy-learning Anti-Spam service custom tailored
to each individual user's behavior. Advanced because on top of
standard Bayesian filtering is also incorporated the use of
Chained Tokens, de-obfuscation, and other enhancements. DSPAM
works great with Sendmail and Exim, and should work well with
any other MTA that supports an external local delivery agent
(postfix, qmail, etc.)

%package -n	%{libname}
Summary:	A library and Mail Delivery Agent for Bayesian spam filtering
Group:         	System/Libraries

%description -n	%{libname}
DSPAM (as in De-Spam) is an open-source project to create a new
kind of anti-spam mechanism, and is currently effective as both a
server-side agent for UNIX email servers and a developer's library
for mail clients, other anti-spam tools, and similar projects
requiring drop-in spam filtering.

The DSPAM agent masquerades as the email server's local delivery
agent and filters/learns spams using an advanced Bayesian
statistical approach (based on Baye's theorem of combined
probabilities) which provides an administratively
maintenance-free, easy-learning Anti-Spam service custom tailored
to each individual user's behavior. Advanced because on top of
standard Bayesian filtering is also incorporated the use of
Chained Tokens, de-obfuscation, and other enhancements. DSPAM
works great with Sendmail and Exim, and should work well with
any other MTA that supports an external local delivery agent
(postfix, qmail, etc.)

%package -n	%{libname}-devel
Summary:	Development library and header files for the %{name} library
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel lib%{name}-devel
Obsoletes:	%{name}-devel lib%{name}-devel
Obsoletes:	libdspam5-devel

%description -n	%{libname}-devel
DSPAM has had its core engine moved into a separate library,
libdspam. This library can be used by developers to provide
'drop-in' spam filtering for their mail client applications,
other anti-spam tools, or similar projects. 

%prep

%setup -q -n %{name}-%{version}
#%patch0 -p1
ln -s tools.sqlite_drv src/tools.sqlite3_drv
ln -s tools.mysql_drv src/tools.mysql4_drv

%build
#sh ./autogen.sh
libtoolize --copy --force; aclocal -I m4; autoheader; automake --add-missing; autoconf
ln -s `which libtool` .

%configure \
    --enable-trusted-user-security \
    --enable-bayesian-dobly \
    --enable-chained-tokens \
    --enable-experimental \
    --enable-bias \
    --enable-domain-scale \
    --enable-delivery-to-stdout \
    --enable-virtual-users \
    --with-dspam-home=/var/dspam \
    --with-userdir-owner=none \
    --with-userdir-group=none \
    --with-dspam-owner=none \
    --with-dspam-group=none \
    --with-signature-life=14 \
    --disable-dependency-tracking \
    --enable-virtual-users \
    --with-logdir=/var/log/dspam \
    --with-storage-driver=sqlite3_drv%{?_with_mysql4:,mysql4_drv}%{?_with_pgsql:,pgsql_drv}%{?_with_db4:,libdb4_drv}

make

%install
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot} 

# make some dirs
install -d %{buildroot}%{_includedir}/dspam
install -d %{buildroot}%{_sysconfdir}/cron.daily
install -d %{buildroot}/var/lib/dspam
install -d %{buildroot}/var/log/dspam
install -d %{buildroot}/var/www/icons
install -d %{buildroot}%{_datadir}/dspam

make install DESTDIR=%{buildroot}

# install devel files
install -m0644 src/*.h %{buildroot}%{_includedir}/dspam/

# install promo icon
install -m0644 webui/htdocs/dspam-logo-small.gif %{buildroot}/var/www/icons/dspam.gif

# provide maintenance scripts
cat > %{buildroot}%{_sysconfdir}/cron.daily/dspam <<EOF
#!/bin/sh
exec %{_bindir}/dspam_clean 2>&1 > /dev/null
EOF
chmod 755 %{buildroot}%{_sysconfdir}/cron.daily/dspam

# install missing file
install -m0644 src/dspam.conf %{buildroot}%{_sysconfdir}/dspam.conf

# cleanup (%%docs)
find . -type f -name "Makefile*" | xargs rm -f

# fix strange perms
#chmod 755 cgi/*.cgi

# fix strange perms (strip cannot access setuid/sgid files...)
chmod 755 %{buildroot}%{_bindir}/*

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%clean
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot} 

%files
%defattr(-,root,root)
%doc README* RELEASE.NOTES CHANGELOG txt
%dir %attr(0750,root,mail) /var/lib/dspam
%dir %attr(0750,root,mail) /var/log/dspam
%attr(0755,root,root) %config(noreplace) %{_sysconfdir}/cron.daily/dspam
%attr(0640,root,mail) %config(noreplace) %{_sysconfdir}/dspam.conf
%attr(0755,root,mail) %{_bindir}/dspam
%attr(0755,root,mail) %{_bindir}/dspamc
%attr(0755,root,mail) %{_bindir}/dspam_admin
%attr(0755,root,root) %{_bindir}/dspam_clean
%attr(0755,root,root) %{_bindir}/dspam_crc
%attr(0755,root,root) %{_bindir}/dspam_dump
%attr(0755,root,root) %{_bindir}/dspam_stats
%attr(0755,root,root) %{_bindir}/dspam_merge
%attr(0755,root,root) %{_bindir}/dspam_2sql
%attr(0755,root,root) %{_bindir}/dspam_logrotate
%attr(0755,root,root) %{_bindir}/dspam_train
%attr(0644,root,root) %{_mandir}/man1/*
#%attr(0644,root,root) %{_datadir}/dspam/*
%attr(0644,root,root) /var/www/icons/dspam.gif

%files -n %{libname}
%defattr(-,root,root)
%doc README* RELEASE.NOTES CHANGELOG
%attr(0755,root,root) %{_libdir}/*.so.*

%files -n %{libname}-devel
%defattr(-,root,root)
%attr(0755,root,root) %{_libdir}/*.so
%attr(0644,root,root) %{_libdir}/*.la
%attr(0755,root,root) %{_libdir}/*.a
%{_includedir}/dspam
%attr(0644,root,root) %{_libdir}/pkgconfig/dspam.pc
%attr(0644,root,root) %{_mandir}/man3/*

%changelog
* Mon Nov 29 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 3.2.3-1mdk
- 3.2.3

* Mon Nov 15 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 3.2.2-1mdk
- 3.2.2

* Mon Nov 01 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 3.2.1-1mdk
- 3.2.1
- drop P1, it's fixed upstream

* Sat Oct 30 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 3.2.0-2mdk
- make it compile on 9.2/10.0
- make the devel package obsolete the older one

* Sat Oct 23 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 3.2.0-1mdk
- 3.2.0
- fix P0
- new %%{major} (again!)
- misc spec file fixes
- drop the weekly purge script

* Thu Jun 17 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 3.0.0-1mdk
- 3.0.0
- fix P0
- new %%{major} (again!)
- use domain-scale instead
- two more binaries is gone

* Fri Apr 16 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 2.10.3-1mdk
- 2.10.3

* Sun Mar 07 2004 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.10-0.2mdk
- 2.10-RC2

* Sun Feb 29 2004 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.10-0.1mdk
- 2.10-RC1
- misc spec file fixes

* Tue Feb 10 2004 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.9.6-1mdk
- 2.9.6

* Sun Jan 25 2004 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.8.3-1mdk
- 2.8.3

* Sun Nov 30 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.8-2mdk
- fix some forgotten stuff and added S1

* Fri Nov 28 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.8-1mdk
- 2.8
- fix P0
- new %%{major}

* Sun Nov 09 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.7.6.10-1mdk
- 2.7.6.10

* Mon Oct 20 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.7.6.8-1mdk
- 2.7.6.8

* Fri Oct 17 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.7.6.4-1mdk
- 2.7.6.4
- fix P0

* Tue Oct 14 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.7.6-2mdk
- use --enable-virtual-users

* Sun Oct 12 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.7.6-1mdk
- 2.7.6
- new P0

* Fri Oct 03 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.7.4-1mdk
- use the mysql driver

* Wed Oct 01 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.7.3-1mdk
- 2.7.3

* Fri Sep 26 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.7.2-1mdk
- 2.7.2

* Wed Sep 24 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.7.1-1mdk
- 2.7.1
- drop P1, it's in there

* Fri Sep 19 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.7.0-1mdk
- 2.7.0
- fix P0
- 2 binaries is no more, may re-appear?
- 1 new binary

* Sun Sep 07 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.6.5.2-2mdk
- fix major
- fix requires and buildrequires

* Sun Sep 07 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.6.5.2-1mdk
- dspam-2.6.5.2

* Tue Sep 02 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.6.5-1mdk
- dspam-2.6.5

* Sun Aug 31 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.6.5-0.5mdk
- dspam-2.6.5-rc1

* Wed Aug 27 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.6.5-0.4mdk
- dspam-2.6.5-beta-2

* Mon Aug 25 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.6.5-0.3mdk
- dspam-2.6.5-beta-1

* Thu Aug 21 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.6.5-0.2mdk
- dspam-2.6.5-alpha-3

* Sun Aug 17 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.6.5-0.1mdk
- dspam-2.6.5-alpha-2

* Tue Aug 12 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.6.4-1mdk
- 2.6.4
- misc spec file fixes

* Fri Aug 01 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.6.3-1mdk
- 2.6.3

* Tue Jul 29 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.6.2.02-1mdk
- 2.6.2.02

* Tue Jul 15 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.6-1mdk
- initial cooker contrib
- added P0
